% This .m file solves the model and estimated the optimum parameters 
%
% INPUT: Cumulative infected data
% OUPUT: Optimum parameter
% Code by: Munsur Rahman, 2017
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc;
clear;
close all;

addpath('./func')
addpath('./data')

global bh alphah gamma bv alphav lamdav eta NH 
global sh0 eh0 ih0 ev0 iv0 C0 tspan
global data d n 

%% section for manual change
data=xlsread('TN.xlsx');
d=data(:,1);

bh=0.9688;
gamma=0.1137;

%%
n=length(data(:,3));
tspan=0:1:n*7;

NH=data(1,4);
SH0=NH;

% fixed parameter
alphav=1/10;
lamdav=1/15;


sh0=SH0/NH; eh0=1/NH; ih0=1/NH; ev0=0.005; iv0=0.005; C0=NH*eh0; % Initial condition

lb=[0.02 1/12 0];
ub=[4 1/4 1];

initial_guess=[0.27 1/10 0.1];

Optimum_value=fmincon('myObj',initial_guess,[],[],[],[],lb,ub);

%------------------------------------

bv=Optimum_value(1);
alphah=Optimum_value(2);
eta = Optimum_value(3);

initial_conditions=[sh0,eh0,ih0,ev0,iv0,C0]; 

[tv, Yv]=ode45('sysfun',tspan,initial_conditions); % ODE45 %

R=Yv(:,6);

%%
p=1;
for j=8:length(R)   
    I2(p)=R(j)-R(j-1);
    p=p+1;
end

time=data(1,3):1:25; % in Weeks
t2=data(1,3)*7:1:25*7;
% Plot data -----------------------
plot(time,d,'ro','LineWidth',2);
hold on;
plot(t2./7,I2*7,'LineWidth',4);
xlabel('Time (Weeks)');
ylabel('Weekly new infected people');

xlim([0 25]);
%ylim([0 150]);

%%

SD=SE3();
val=[Optimum_value; SD]';

t= 1.96;
ci1=[Optimum_value(1)-t*SD(1), Optimum_value(1)+t*SD(1)];
ci2= [Optimum_value(2)-t*SD(2), Optimum_value(2)+t*SD(2)];
ci3= [Optimum_value(3)*100-t*SD(3), Optimum_value(3)*100+t*SD(3)];
ci=[ci1; ci2; ci3];
Final_val=[val ci];
R0=sqrt((bh*bv*alphav)/(gamma*lamdav*(alphav+lamdav)))
clearvars -except Final_val;