% This .m file solves the model and estimated the optimum parameters 
%
% INPUT: Cumulative infected data
% OUPUT: Optimum parameter
% Code by: Munsur Rahman, 2017
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc;
clear;
close all;

addpath('./ode45c')
addpath('./data')

global bh alphah gamma bv alphav lamdav eta NH 
global sh0 eh0 ih0 ev0 iv0 C0 tspan
global data d n

%% section for manual change
data=xlsread('TN.xlsx');
d=data(:,2);

%%
n=length(data(:,3));
tspan=0:1:n*7;

NH=data(1,4);
SH0=NH;

% fixed parameter
alphav=1/10;
lamdav=1/15;


sh0=SH0/NH; eh0=1/NH; ih0=1/NH; ev0=0.005; iv0=0.005; C0=NH*eh0; % Initial condition

lb=[0.1 0.02 1/12 1/12 0];
ub=[15 4 1/4 1/4 1];


initial_guess=[0.57 0.27 1/6 1/5 0.1];

Optimum_value=fmincon('myObj',initial_guess,[],[],[],[],lb,ub);

%------------------------------------
bh=Optimum_value(1); 
bv=Optimum_value(2);
alphah=Optimum_value(3);
gamma=Optimum_value(4);
eta = Optimum_value(5);

initial_conditions=[sh0,eh0,ih0,ev0,iv0,C0]; 

[tv, Yv]=ode45('sysfun',tspan,initial_conditions); % ODE45 %

yy=Yv(:,6);

time=1:1:n; % in Weeks

% Plot data -----------------------
plot(time,d,'ro','LineWidth',0.5);
hold on;
plot(tv./7,yy,'LineWidth',1);
xlabel('Time (Weeks)');
ylabel('Cumulative infected people');
 % Calcualte Basic Reproduction number
%R0=sqrt((bh*bv*alphav)/(gamma*lamdav*(alphav+lamdav)))
SD=SE5();
Final_val=[Optimum_value; SD]';
%clearvars -except Final_val;