% This .m file calculate peak prevalence and final outbreak size for reducing contact
%
% INPUT: mean estimated optimum parameter
% OUPUT:peak prevalence and final outbreak size for reducing contact
% Code by: Munsur Rahman, 2017
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clc;
clear all;
close all;

global bh alphah gamma bv alphav lamdav eta NH 
global sh0 eh0 ih0 ev0 iv0 C0 ni0 tspan

tspan=0:1:25*7;
NH=37928;

alphav=1/10;
lamdav=1/15;



alphah=0.1425;
gamma=0.1050;
eta = 0.073;


betah=0.9011;
betav=0.0985;

SH0=NH; 
sh0=SH0/NH; eh0=1/NH; ih0=1/NH; ev0=0.005; iv0=0.005; C0=NH*eh0; ni0=0;

initial_conditions=[sh0,eh0,ih0,ev0,iv0,C0, ni0]; 

fi=0:0.01:1;

%% Prevention and control
for i=1:length(fi)
bh=(1-fi(i))*betah;
bv=(1-fi(i))*betav;
[tv, Yv]=ode45('sysfun',tspan,initial_conditions); %ODE45 %
E=Yv(:,2)*NH;
I=Yv(:,3)*NH;
add=E+I;
Pv=add/NH;
peak_pv(i)=max(Pv);  % Peak Prevalance

NI=Yv(:,7);
New_infection(i)=NI(end); % New infection 

end

figure1 = figure;

subplot(2,1,1,'Parent',figure1,'FontSize',20);
plot(fi,peak_pv.*100,'LineWidth',4);
xlabel('Proportion reduction of contact, \phi','FontSize',20);
ylabel('Peak Prevelence(%)','FontSize',20);
axis([0 1 0 100]);

subplot(2,1,2,'Parent',figure1,'FontSize',20);
plot(fi, (New_infection./NH).*100, 'LineWidth',4);
xlabel('Proportion reduction of contact, \phi','FontSize',20)
ylabel('Final Outbreak size (%)','FontSize',20)
axis([0 1 0 100]);
