function SD=SE5

global bh alphah gamma bv alphav lamdav eta NH 
global sh0 eh0 ih0 ev0 iv0 C0 tspan
global d n

h= 1e-40;  % Complex step size


bhatc=bh+1i*h;
bmc= bv+1i*h;
ahc= alphah+ 1i*h;
ghc= gamma + 1i*h;
etac = eta + 1i*h;
%-----------------------------
% solve the system with out perturbation 
    function dx= model(t,x)
        dx = [-bh*x(1)*x(5); bh*x(1)*x(5)-alphah*x(2); ...
              alphah*x(2)-gamma*x(3);bv*x(3)*(1-x(4)-x(5))-(lamdav+alphav)*x(4); ...
              alphav*x(4)-lamdav*x(5); eta*alphah*x(2)*NH];
    end
%-----------------------------
% solve the system with perturbed paramater
   function dx1= sens1(t,x)  % bhat
        dx1 = [-bhatc*x(1)*x(5); bhatc*x(1)*x(5)-alphah*x(2); ...
              alphah*x(2)-gamma*x(3);bv*x(3)*(1-x(4)-x(5))-(lamdav+alphav)*x(4); ...
              alphav*x(4)-lamdav*x(5); eta*alphah*x(2)*NH];
   end
    function dx2= sens2(t,x)  % bm
        dx2 = [-bh*x(1)*x(5); bh*x(1)*x(5)-alphah*x(2); ...
              alphah*x(2)-gamma*x(3);bmc*x(3)*(1-x(4)-x(5))-(lamdav+alphav)*x(4); ...
              alphav*x(4)-lamdav*x(5); eta*alphah*x(2)*NH];
    end
    function dx3= sens3(t,x)  % ah
        dx3 = [-bh*x(1)*x(5); bh*x(1)*x(5)-ahc*x(2); ...
              ahc*x(2)-gamma*x(3);bv*x(3)*(1-x(4)-x(5))-(lamdav+alphav)*x(4); ...
              alphav*x(4)-lamdav*x(5); eta*ahc*x(2)*NH];
    end
    function dx4= sens4(t,x) % gh 
        dx4 = [-bh*x(1)*x(5); bh*x(1)*x(5)-alphah*x(2); ...
              alphah*x(2)-ghc*x(3);bv*x(3)*(1-x(4)-x(5))-(lamdav+alphav)*x(4); ...
              alphav*x(4)-lamdav*x(5); eta*alphah*x(2)*NH];
    end
    function dx5= sens5(t,x) % eta
        dx5 = [-bh*x(1)*x(5); bh*x(1)*x(5)-alphah*x(2); ...
              alphah*x(2)-gamma*x(3);bv*x(3)*(1-x(4)-x(5))-(lamdav+alphav)*x(4); ...
              alphav*x(4)-lamdav*x(5); etac*alphah*x(2)*NH];
    end

% solve ODE at e_i , where e_j is the jth parameter
initial_conditions=[sh0,eh0,ih0,ev0,iv0,C0]; 
[t,x]= ode45(@model, tspan, initial_conditions);
% solution at e_j + ih, where e_j is the jth  parameter  
[t1,s1]= ode45c(@sens1, tspan, initial_conditions);
[t2,s2]= ode45c(@sens2, tspan, initial_conditions);
[t3,s3]= ode45c(@sens3, tspan, initial_conditions);
[t4,s4]= ode45c(@sens4, tspan, initial_conditions);
[t5,s5]= ode45c(@sens5, tspan, initial_conditions);
%-----------------------------

ss1=imag(s1(8:7:end,6))/h;  % bh
ss2=imag(s2(8:7:end,6))/h;  % bm
ss3=imag(s3(8:7:end,6))/h;  % ah 
ss4=imag(s4(8:7:end,6))/h;  % gh
ss5=imag(s5(8:7:end,6))/h;  % eta
%-----------------------------
 M= [ss1, ss2, ss3 ss4, ss5];
%visualize
% figure()
% plot(M(:,1),'.');
% hold on 
% plot(M(:,2),'*');
% hold on 
% plot(M(:,3),'o');
%  
% hold on 
% plot(M(:,4),'>');
% hold on 
% plot(M(:,5));
% legend('dP/d\beta_h','dP/d\beta_m','dP/d\alpha_h','dP/d\gamma_h','dP/d\eta_h','Location','northwest')
% axis tight
% title('Yap')
% 
% figureHandle=gcf;
% set(findall(figureHandle,'type','text'),'fontsize',14)
% set(gca,'fontsize',14)

% sensitivity matrix

 %-----------------------------
%-----------------------------
% Compute standard error
xw= x(8:7:end,6);
J= sum((xw-d).^2);
sigma2= J/(n-4);
MM=inv(M'*M);
dM= diag(MM);
sd= sqrt(sigma2.*dM);
sd=sd';

SD=[sd(1) sd(2) sd(3)  sd(4) sd(5)*100];

end


